==> esup-canal-mailto-1.0.1.zip: CMailTo-1.0.1/source/org/esupportail/portal/channels/CMailTo/MailExceptions/MalFormedMailException.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal :
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/

package org.esupportail.portal.channels.CMailTo.MailExceptions;


public class MalFormedMailException extends Exception {
    
    private String field;
    protected String value = null;
    
    /**
	 * Constructor
	 */
	public MalFormedMailException(){
        super();		    
    }
	
	/**
	 * Constructor
	 */
	public MalFormedMailException(String s){
        super();
        field = s;
    }
	
	/**
	 * Return a string form of this exception
	 */
	public String toString() {
	    
	    String retour = "Le mail est mal form.";
	    if (field!=null){
	        retour += "Le champ '"+field+"' est mal form : "+value; 	            
	    }
	    
		return retour;
		
	}
    
}

==> esup-canal-mailto-2.1.zip: CMailTo-2.1/source/org/esupportail/portal/channels/CMailTo/MailExceptions/MalFormedMailException.java <==
/*
ESUP-portail is a french academic project developed under the GPL (General Public License) augmented according to the following :
A binary or source file developped by ESUP-portail can be used or compiled with products under Apache license.
The official english text of the GPL can be found here : http://www.gnu.org/licenses/gpl.html .
A non official french translation can be found here : http://www.linux-France.org/article/these/gpl.html .
The different kinds of licenses governing the products developed by the Apache foundation can be found here : http://www.apache.org/licenses .
It follows that you can as well as use download contents as well modify and redistribute them provided you respect the GPL terms.
Downloading and using such contents do not provide any guaranty.
Be sure that you have well understood the terms of the license before using the contents it covers.
The ESUP-portail distribution includes the following distributions :
    * UPortal :
      software developed by JA-SIG (Java Architecture - Special Interest Group)
      You can find the license page here : http://mis105.udel.edu/ja-sig/uportal/license.html
    * CAS :
      SSO solution developed by Yale University
      You can find the project page here : http://www.yale.edu/tp/auth
    * Cocoon :
      XML framework distributed by the Apache foundation under Apache license;
      Please find the full text here : http://cocoon.apache.org/2.1/license.html
    * Mod_dav:
      A DAV module for Apache web server
      You can find the project page here : http://www.webdav.org/mod_dav
    * IMP :
      webmail from Horde application framework
      You can find the project page here : http://www.horde.org
    * . To be completed
*/

package org.esupportail.portal.channels.CMailTo.MailExceptions;

public class MalFormedMailException extends Exception {
    /**
	 * 
	 */
	private static final long serialVersionUID = -8361945966859257694L;
	private String field;
    protected String value = null;
    
    /**
	 * Constructor
	 */
	public MalFormedMailException(){
        super();		    
    }
	
	/**
	 * Constructor
	 */
	public MalFormedMailException(String s){
        super();
        field = s;
    }
	
	/**
	 * Return a string form of this exception
	 */
	public String toString() {
	    String retour = "Le mail est mal form\u00E9. ";
	    if (field!=null){
	    	if ( (value!=null) && (!value.equals("")) )
		        retour += "Le champ '"+field+"' est mal form\u00E9 : '"+value+"'."; 	
	    	else
	    		retour += "Le champ '"+field+"' est obligatoire or il est vide."; 	            
	    }	    
		return retour;
	}
}
